# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2025-04-07

### Changed
- Updated package name to use hyphens instead of underscores
- Fixed PyPI badge in README.md

## [0.1.0] - 2025-04-07

### Added
- Initial release
- Middleware to add Web Monetization payment pointer to HTTP headers
- Template tag to insert the monetization meta tag in templates
- Simple configuration through settings.py
- Tests for middleware and template tags 